nashorn/src/jdk/nashorn/internal/ir/LoopNode.java
changeset 17524 703643aeb0d6
parent 17523 cb4a7c901e0d
child 18867 bc91e3fcc5ba
--- a/nashorn/src/jdk/nashorn/internal/ir/LoopNode.java	Tue May 07 14:36:57 2013 +0200
+++ b/nashorn/src/jdk/nashorn/internal/ir/LoopNode.java	Tue May 07 14:43:17 2013 +0200
@@ -49,14 +49,15 @@
     /**
      * Constructor
      *
      * @param token   token
      * @param finish  finish
      * @param test    test, or null if infinite loop
      * @param body    loop body
      * @param controlFlowEscapes controlFlowEscapes
      */
-    protected LoopNode(final long token, final int finish, final Node test, final Block body, final boolean controlFlowEscapes) {
-        super(token, finish, new Label("while_break"));
+    protected LoopNode(final int lineNumber, final long token, final int finish, final Node test, final Block body, final boolean controlFlowEscapes) {
+        super(lineNumber, token, finish, new Label("while_break"));
         this.continueLabel = new Label("while_continue");
         this.test = test;
         this.body = body;
@@ -49,14 +49,15 @@
      * Constructor
      *
-     * @param token   token
-     * @param finish  finish
-     * @param test    test, or null if infinite loop
-     * @param body    loop body
+     * @param lineNumber         lineNumber
+     * @param token              token
+     * @param finish             finish
+     * @param test               test, or null if infinite loop
+     * @param body               loop body
      * @param controlFlowEscapes controlFlowEscapes
      */